@@ -9,7 +9,7 @@ dUtility <- function (x, xm, method = "IL1")
         for (i in 1:dim(x)[2]) {
             a[, i] <- abs((x[, i] - xm[, i])/sd(x[, i]) * sqrt(2))
         }
-        infLoss1 <- 1/dim(x)[2] * sum(a)
+        infLoss1 <- 1/(dim(x)[2]*dim(x)[1]) * sum(a)
         return(infLoss1)
     }
     if (method == "eigen") {
